@@ -19,7 +19,7 @@ var alienSpeedRatio = 0.85 //The speed increase on the next level
 
 var level = 0;
 var startlives = 3; //Edit this to cheat!
-var livesindication;
+var livesindication = new Array();
 var lives;
 
 function cmdNotRunning() {
@@ -58,7 +58,6 @@ function cmdNewGame() {
     dropBombChance = 100;
 
     lives = startlives;
-    livesindication = new Array(lives - 1);
     createLivesIndication();
 
     //Hide the logos
@@ -163,7 +162,7 @@ function cmdLevelComplete() {
     }
 
     //New Life every 10 levels
-    if (((level % 10) == 0) && (lives < 8)) {
+    if (((level % 5) == 0) && (lives < 8)) {
         lives++;
         createLivesIndication();
         board.displayMessage("Extra Life Gained!");
@@ -207,6 +206,8 @@ function cmdPause() {
     //Start the animation timers
     heartbeat.running = false;
     alienanimation.running = false;
+
+    accelerometer.stop();
 }
 
 function screenTap() {
@@ -262,7 +263,7 @@ function createLivesIndication() {
 }
 
 function destroyLivesIndication() {
-    for (var i = 0; i < startlives-1; ++i) {
+    for (var i = 0; i < lives-1; ++i) {
         if(livesindication[i]) {
             livesindication[i].destroy();
             livesindication[i] = null;
@@ -284,7 +285,6 @@ function shipHit() {
         mysteryShipSound.stop();
     }
 
-
     if (lives > 1) {
        cmdLifeLost();
     } else { //game over
